@@ -157,8 +157,8 @@ public class FixedBCPKIXCertPathReviewer extends PKIXCertPathReviewer
         // a) done
 
         // b)
-
-        validDate = getValidDate(pkixParams.getBaseOfBase());
+        currentDate = new Date();
+        validDate = getValidityDate(pkixParams.getBaseOfBase(), currentDate);
 
         // c) part of pkixParams
 
@@ -175,6 +175,13 @@ public class FixedBCPKIXCertPathReviewer extends PKIXCertPathReviewer
         policyTree = null;
     }
     
+    protected static Date getValidityDate(PKIXParameters paramsPKIX, Date currentDate)
+    {
+        Date validityDate = paramsPKIX.getDate();
+
+        return null == validityDate ? currentDate : validityDate;
+    }
+    
     /**
      * Creates a PKIXCertPathReviewer and initializes it with the given {@link CertPath} and {@link PKIXParameters} params
      * @param certPath the {@link CertPath} to validate
